summaryrefslogtreecommitdiff
path: root/gcc/ipa-ref-inline.h
diff options
context:
space:
mode:
authorhubicka <hubicka@138bc75d-0d04-0410-961f-82ee72b054a4>2012-04-18 09:57:53 +0000
committerhubicka <hubicka@138bc75d-0d04-0410-961f-82ee72b054a4>2012-04-18 09:57:53 +0000
commit04ec15fab9e10f969c2826268e471a0ab08ebd58 (patch)
tree557443c354065839ba2b0035e3d525377e5293fa /gcc/ipa-ref-inline.h
parente24c256de02eecbde481f48e19ed3779f4020739 (diff)
downloadgcc-04ec15fab9e10f969c2826268e471a0ab08ebd58.tar.gz
* lto-symtab.c (lto_cgraph_replace_node): Update.
* cgraphbuild.c (record_reference, record_type_list, record_eh_tables, mark_address, mark_load, mark_store): Update. * cgraph.c (cgraph_same_body_alias, dump_cgraph_node, cgraph_create_virtual_clone, cgraph_for_node_thunks_and_aliases): Update. * cgraph.h (symtab_node_def, symtab_node, const_symtab_node): Remove. (cgraph_alias_aliased_node, varpool_alias_aliased_node): Update. * reload.c: Fix typo in comment. * rtlanal.c: Likewise. * tree-emultls.c (gen_emutls_addr): Update. * ipa-reference.c (analyze_function): Update. * cgraphunit.c (cgraph_analyze_function, cgraph_process_same_body_aliases, assemble_thunks_and_aliases): Update. * ipa-ref.c (ipa_record_reference): Reorg to avoid reference types. (ipa_remove_reference): Likewise. (ipa_remove_all_refering): Rename to ... (ipa_remove_all_referring): ... this one; update. (ipa_dump_references): Update. (ipa_dump_referring): Update. (ipa_clone_references): Update. (ipa_clone_refering): Rename to ... (ipa_clone_referring): ... this one; update. (ipa_ref_cannot_lead_to_return): Update. (ipa_ref_has_aliases_p): Update. * ipa-ref.h (symtab_node_def, symtab_node, const_symtab_node): New forward typedefs. (ipa_ref_type): Remove. (ipa_ref_ptr_u): Remove. (ipa_ref): Remove referencing, refered, refered_index, refering_type and refered_type; add referring, referred and referred_index. (ipa_ref_list): Rename refering to referring. (ipa_record_reference, ipa_remove_all_referring, ipa_dump_referring, ipa_clone_references, ipa_clone_referring): Update prototypes. * lto-cgraph.c (referenced_from_other_partition_p): Update. (lto_output_ref): Update. (add_references): Update. (input_varpool_node): Update. (input_refs): Update. * ipa-ref-inline.h (ipa_ref_node): Update. (ipa_ref_varpool_node): Update. (ipa_ref_referring_node); Update. (ipa_ref_referring_varpool_node): Update. (ipa_ref_referring_ref_list); Update. (ipa_ref_referred_ref_list): Update. (ipa_ref_list_first_referring): Update. (ipa_empty_ref_list): Update. (ipa_ref_list_refering_iterate): Rename to ... (ipa_ref_list_referring_iterate): ... this one. * cse.c: Update comment. * ipa-utils.c (ipa_reverse_postorder): Update. * tree-ssa-alias.c: Update. * ipa-inline.c (reset_edge_caches): Update. (update_caller_keys): Update. * ipa-inline.h: Update comments. * jump.c: Update comment. * alias.c: Likewise. * ipa.c (process_references): Update. (cgraph_remove_unreachable_nodes): Likewise. (ipa_discover_readonly_nonaddressable_var): Likewise. (cgraph_address_taken_from_non_vtable_p): Likewise. * trans-mem.c (ipa_tm_execute): Update. * simplify-rtx.c: Fix comment. * rtl.c: Fix comment. * symtab.c (symtab_unregister_node): Update. * varpool.c (dump_varpool_node): Update. (varpool_analyze_pending_decls): Update. (assemble_aliases): Update. (varpool_for_node_and_aliases): Update. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@186564 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/ipa-ref-inline.h')
-rw-r--r--gcc/ipa-ref-inline.h48
1 files changed, 19 insertions, 29 deletions
diff --git a/gcc/ipa-ref-inline.h b/gcc/ipa-ref-inline.h
index b9c3f533534..636af145789 100644
--- a/gcc/ipa-ref-inline.h
+++ b/gcc/ipa-ref-inline.h
@@ -19,61 +19,51 @@ You should have received a copy of the GNU General Public License
along with GCC; see the file COPYING3. If not see
<http://www.gnu.org/licenses/>. */
/* Return callgraph node REF is refering. */
static inline struct cgraph_node *
ipa_ref_node (struct ipa_ref *ref)
{
- gcc_assert (ref->refered_type == IPA_REF_CGRAPH);
- return ref->refered.cgraph_node;
+ return cgraph (ref->referred);
}
/* Return varpool node REF is refering. */
static inline struct varpool_node *
ipa_ref_varpool_node (struct ipa_ref *ref)
{
- gcc_assert (ref->refered_type == IPA_REF_VARPOOL);
- return ref->refered.varpool_node;
+ return varpool (ref->referred);
}
/* Return cgraph node REF is in. */
static inline struct cgraph_node *
-ipa_ref_refering_node (struct ipa_ref *ref)
+ipa_ref_referring_node (struct ipa_ref *ref)
{
- gcc_assert (ref->refering_type == IPA_REF_CGRAPH);
- return ref->refering.cgraph_node;
+ return cgraph (ref->referring);
}
/* Return varpool node REF is in. */
static inline struct varpool_node *
-ipa_ref_refering_varpool_node (struct ipa_ref *ref)
+ipa_ref_referring_varpool_node (struct ipa_ref *ref)
{
- gcc_assert (ref->refering_type == IPA_REF_VARPOOL);
- return ref->refering.varpool_node;
+ return varpool (ref->referring);
}
/* Return reference list REF is in. */
static inline struct ipa_ref_list *
-ipa_ref_refering_ref_list (struct ipa_ref *ref)
+ipa_ref_referring_ref_list (struct ipa_ref *ref)
{
- if (ref->refering_type == IPA_REF_CGRAPH)
- return &ipa_ref_refering_node (ref)->symbol.ref_list;
- else
- return &ipa_ref_refering_varpool_node (ref)->symbol.ref_list;
+ return &ref->referring->symbol.ref_list;
}
/* Return reference list REF is in. */
static inline struct ipa_ref_list *
-ipa_ref_refered_ref_list (struct ipa_ref *ref)
+ipa_ref_referred_ref_list (struct ipa_ref *ref)
{
- if (ref->refered_type == IPA_REF_CGRAPH)
- return &ipa_ref_node (ref)->symbol.ref_list;
- else
- return &ipa_ref_varpool_node (ref)->symbol.ref_list;
+ return &ref->referred->symbol.ref_list;
}
/* Return first reference in LIST or NULL if empty. */
@@ -86,14 +76,14 @@ ipa_ref_list_first_reference (struct ipa_ref_list *list)
return VEC_index (ipa_ref_t, list->references, 0);
}
/* Return first refering ref in LIST or NULL if empty. */
static inline struct ipa_ref *
-ipa_ref_list_first_refering (struct ipa_ref_list *list)
+ipa_ref_list_first_referring (struct ipa_ref_list *list)
{
- if (!VEC_length (ipa_ref_ptr, list->refering))
+ if (!VEC_length (ipa_ref_ptr, list->referring))
return NULL;
- return VEC_index (ipa_ref_ptr, list->refering, 0);
+ return VEC_index (ipa_ref_ptr, list->referring, 0);
}
/* Clear reference list. */
@@ -101,7 +91,7 @@ ipa_ref_list_first_refering (struct ipa_ref_list *list)
static inline void
ipa_empty_ref_list (struct ipa_ref_list *list)
{
- list->refering = NULL;
+ list->referring = NULL;
list->references = NULL;
}
@@ -115,5 +105,5 @@ ipa_ref_list_nreferences (struct ipa_ref_list *list)
#define ipa_ref_list_reference_iterate(L,I,P) \
VEC_iterate(ipa_ref_t, (L)->references, (I), (P))
-#define ipa_ref_list_refering_iterate(L,I,P) \
- VEC_iterate(ipa_ref_ptr, (L)->refering, (I), (P))
+#define ipa_ref_list_referring_iterate(L,I,P) \
+ VEC_iterate(ipa_ref_ptr, (L)->referring, (I), (P))
@@ -19,61 +19,51 @@ You should have received a copy of the GNU General Public License
along with GCC; see the file COPYING3. If not see
<http://www.gnu.org/licenses/>. */
-/* Return callgraph node REF is refering. */
+/* Return callgraph node REF is referring. */
static inline struct cgraph_node *
ipa_ref_node (struct ipa_ref *ref)
@@ -19,61 +19,51 @@ You should have received a copy of the GNU General Public License
}
-/* Return varpool node REF is refering. */
+/* Return varpool node REF is referring. */
static inline struct varpool_node *
ipa_ref_varpool_node (struct ipa_ref *ref)
@@ -86,14 +76,14 @@ ipa_ref_list_first_reference (struct ipa_ref_list *list)
return VEC_index (ipa_ref_t, list->references, 0);
}
-/* Return first refering ref in LIST or NULL if empty. */
+/* Return first referring ref in LIST or NULL if empty. */
static inline struct ipa_ref *